{%- extends "layout.html" %}
{% block content %}
  <h1 id="search-documentation">{{ lang.t('search.placeholder') }}</h1>
  <p>
    {% trans %}To search the documentation, use the search bar in the header.
    You can use the "F" or "S" keys as shortcuts to search.{% endtrans %}
  </p>
{% endblock %}
