/* https://google-webfonts-helper.herokuapp.com/fonts/titillium-web?subsets=latin */

/* titillium-web-300 - latin */
@font-face {
  font-family: 'Titillium Web';
  font-style: normal;
  font-weight: 300;
  src: url('titillium-web/titillium-web-v6-latin-300.eot'); /* IE9 Compat Modes */
  src: local('Titillium Web Light'), local('TitilliumWeb-Light'),
       url('titillium-web/titillium-web-v6-latin-300.eot?#iefix') format('embedded-opentype'), /* IE6-IE8 */
       url('titillium-web/titillium-web-v6-latin-300.woff2') format('woff2'), /* Super Modern Browsers */
       url('titillium-web/titillium-web-v6-latin-300.woff') format('woff'), /* Modern Browsers */
       url('titillium-web/titillium-web-v6-latin-300.ttf') format('truetype'), /* Safari, Android, iOS */
       url('titillium-web/titillium-web-v6-latin-300.svg#TitilliumWeb') format('svg'); /* Legacy iOS */
}

/* titillium-web-regular - latin */
@font-face {
  font-family: 'Titillium Web';
  font-style: normal;
  font-weight: 400;
  src: url('titillium-web/titillium-web-v6-latin-regular.eot'); /* IE9 Compat Modes */
  src: local('Titillium Web Regular'), local('TitilliumWeb-Regular'),
       url('titillium-web/titillium-web-v6-latin-regular.eot?#iefix') format('embedded-opentype'), /* IE6-IE8 */
       url('titillium-web/titillium-web-v6-latin-regular.woff2') format('woff2'), /* Super Modern Browsers */
       url('titillium-web/titillium-web-v6-latin-regular.woff') format('woff'), /* Modern Browsers */
       url('titillium-web/titillium-web-v6-latin-regular.ttf') format('truetype'), /* Safari, Android, iOS */
       url('titillium-web/titillium-web-v6-latin-regular.svg#TitilliumWeb') format('svg'); /* Legacy iOS */
}

/* titillium-web-italic - latin */
@font-face {
  font-family: 'Titillium Web';
  font-style: italic;
  font-weight: 400;
  src: url('titillium-web/titillium-web-v6-latin-italic.eot'); /* IE9 Compat Modes */
  src: local('Titillium Web Italic'), local('TitilliumWeb-Italic'),
       url('titillium-web/titillium-web-v6-latin-italic.eot?#iefix') format('embedded-opentype'), /* IE6-IE8 */
       url('titillium-web/titillium-web-v6-latin-italic.woff2') format('woff2'), /* Super Modern Browsers */
       url('titillium-web/titillium-web-v6-latin-italic.woff') format('woff'), /* Modern Browsers */
       url('titillium-web/titillium-web-v6-latin-italic.ttf') format('truetype'), /* Safari, Android, iOS */
       url('titillium-web/titillium-web-v6-latin-italic.svg#TitilliumWeb') format('svg'); /* Legacy iOS */
}

/* titillium-web-700 - latin */
@font-face {
  font-family: 'Titillium Web';
  font-style: normal;
  font-weight: 700;
  src: url('titillium-web/titillium-web-v6-latin-700.eot'); /* IE9 Compat Modes */
  src: local('Titillium Web Bold'), local('TitilliumWeb-Bold'),
       url('titillium-web/titillium-web-v6-latin-700.eot?#iefix') format('embedded-opentype'), /* IE6-IE8 */
       url('titillium-web/titillium-web-v6-latin-700.woff2') format('woff2'), /* Super Modern Browsers */
       url('titillium-web/titillium-web-v6-latin-700.woff') format('woff'), /* Modern Browsers */
       url('titillium-web/titillium-web-v6-latin-700.ttf') format('truetype'), /* Safari, Android, iOS */
       url('titillium-web/titillium-web-v6-latin-700.svg#TitilliumWeb') format('svg'); /* Legacy iOS */
}

