/* https://google-webfonts-helper.herokuapp.com/fonts/open-sans?subsets=latin */

/* open-sans-300 - latin */
@font-face {
  font-family: 'Open Sans';
  font-style: normal;
  font-weight: 300;
  src: url('open-sans/open-sans-v15-latin-300.eot'); /* IE9 Compat Modes */
  src: local('Open Sans Light'), local('OpenSans-Light'),
       url('open-sans/open-sans-v15-latin-300.eot?#iefix') format('embedded-opentype'), /* IE6-IE8 */
       url('open-sans/open-sans-v15-latin-300.woff2') format('woff2'), /* Super Modern Browsers */
       url('open-sans/open-sans-v15-latin-300.woff') format('woff'), /* Modern Browsers */
       url('open-sans/open-sans-v15-latin-300.ttf') format('truetype'), /* Safari, Android, iOS */
       url('open-sans/open-sans-v15-latin-300.svg#OpenSans') format('svg'); /* Legacy iOS */
}

/* open-sans-regular - latin */
@font-face {
  font-family: 'Open Sans';
  font-style: normal;
  font-weight: 400;
  src: url('open-sans/open-sans-v15-latin-regular.eot'); /* IE9 Compat Modes */
  src: local('Open Sans Regular'), local('OpenSans-Regular'),
       url('open-sans/open-sans-v15-latin-regular.eot?#iefix') format('embedded-opentype'), /* IE6-IE8 */
       url('open-sans/open-sans-v15-latin-regular.woff2') format('woff2'), /* Super Modern Browsers */
       url('open-sans/open-sans-v15-latin-regular.woff') format('woff'), /* Modern Browsers */
       url('open-sans/open-sans-v15-latin-regular.ttf') format('truetype'), /* Safari, Android, iOS */
       url('open-sans/open-sans-v15-latin-regular.svg#OpenSans') format('svg'); /* Legacy iOS */
}

/* open-sans-italic - latin */
@font-face {
  font-family: 'Open Sans';
  font-style: italic;
  font-weight: 400;
  src: url('open-sans/open-sans-v15-latin-italic.eot'); /* IE9 Compat Modes */
  src: local('Open Sans Italic'), local('OpenSans-Italic'),
       url('open-sans/open-sans-v15-latin-italic.eot?#iefix') format('embedded-opentype'), /* IE6-IE8 */
       url('open-sans/open-sans-v15-latin-italic.woff2') format('woff2'), /* Super Modern Browsers */
       url('open-sans/open-sans-v15-latin-italic.woff') format('woff'), /* Modern Browsers */
       url('open-sans/open-sans-v15-latin-italic.ttf') format('truetype'), /* Safari, Android, iOS */
       url('open-sans/open-sans-v15-latin-italic.svg#OpenSans') format('svg'); /* Legacy iOS */
}

/* open-sans-700 - latin */
@font-face {
  font-family: 'Open Sans';
  font-style: normal;
  font-weight: 700;
  src: url('open-sans/open-sans-v15-latin-700.eot'); /* IE9 Compat Modes */
  src: local('Open Sans Bold'), local('OpenSans-Bold'),
       url('open-sans/open-sans-v15-latin-700.eot?#iefix') format('embedded-opentype'), /* IE6-IE8 */
       url('open-sans/open-sans-v15-latin-700.woff2') format('woff2'), /* Super Modern Browsers */
       url('open-sans/open-sans-v15-latin-700.woff') format('woff'), /* Modern Browsers */
       url('open-sans/open-sans-v15-latin-700.ttf') format('truetype'), /* Safari, Android, iOS */
       url('open-sans/open-sans-v15-latin-700.svg#OpenSans') format('svg'); /* Legacy iOS */
}

