{#
<!--
  Copyright (c) 2016-2019 Martin Donath <martin.donath@squidfunk.com>
  Copyright (c) 2018-2019 Blue Brain Project/EPFL

  Permission is hereby granted, free of charge, to any person obtaining a copy
  of this software and associated documentation files (the "Software"), to
  deal in the Software without restriction, including without limitation the
  rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
  sell copies of the Software, and to permit persons to whom the Software is
  furnished to do so, subject to the following conditions:

  The above copyright notice and this permission notice shall be included in
  all copies or substantial portions of the Software.

  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
  FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT. IN NO EVENT SHALL THE
  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
  IN THE SOFTWARE.
-->
#}

<!-- Application header -->
<header class="md-header" data-md-component="header">

  <!-- Top-level navigation -->
  <nav class="md-header-nav md-grid">
    <div class="md-flex">

      <!-- Link to home -->
      <div class="md-flex__cell md-flex__cell--shrink">
        <a href="{{ config.site_url | default(nav.homepage.url, true) | url }}"
            title="{{ config.site_name }}"
            class="md-header-nav__button md-logo">
          {% if config.theme.logo.icon %}
            <i class="md-icon">{{ config.theme.logo.icon }}</i>
          {% else %}
            <img src="{{ config.theme.logo | url }}" width="24" height="24" />
          {% endif %}
        </a>
      </div>

      <!-- Button to toggle drawer -->
      <div class="md-flex__cell md-flex__cell--shrink">
        <label class="md-icon md-icon--menu md-header-nav__button"
            for="__drawer"></label>
      </div>

      {# begin edits #}
      <!-- Home button to ecosystem -->
      <div class="md-flex__cell md-flex__cell--shrink">
        <div class="documentation-homepage-icon">
          <!-- this href will be overwritten by utils.js -->
          <a href="#" id="homepageLink">
            <i class="fa fa-home"></i>
          </a>
        </div>
      </div>
      {# end edits #}

      <!-- Header title -->
      <div class="md-flex__cell md-flex__cell--stretch">
        <div class="md-flex__ellipsis md-header-nav__title"
            data-md-component="title">
          {# begin edits #}
          {% if config.site_name == page.title %}
          <a href="{{ config.title_url | default(nav.homepage.url, true) | url }}"
              title="{{ config.site_name }}">
          {% if theme_title_prefix and not theme_use_original_style %}<span class="md-header-nav__prefix">
          {{ theme_title_prefix }}</span> &ndash;{% endif %}
          {{ config.site_name }}
          {%- if version and not theme_use_original_style %}<span class="md-header-nav__version">
          {{ version }}</span>{% endif -%}
          </a>
        {% else %}
          <span class="md-header-nav__topic">
            <a href="{{ config.title_url | default(nav.homepage.url, true) | url }}"
                title="{{ config.site_name }}">
            {% if theme_title_prefix and not theme_use_original_style %}<span class="md-header-nav__prefix">
            {{ theme_title_prefix }}</span> &ndash;{% endif %}
            {{ config.site_name }}
            {%- if version and not theme_use_original_style %}<span class="md-header-nav__version">
            {{ version }}</span>{% endif -%}
            </a>
          </span>
          <span class="md-header-nav__topic">
            <a href="{{ '' | url }}" title="{{ page.title }}">
            {% if theme_title_prefix and not theme_use_original_style %}<span class="md-header-nav__prefix">
            {{ theme_title_prefix }}</span> &ndash;{% endif %}
            {% if not theme_use_original_style %}{{ config.site_name }} &ndash;{% endif %}
            {{ page.title }}
            {%- if version and not theme_use_original_style %}<span class="md-header-nav__version">
            {{ version }}</span>{% endif -%}
            </a>
          </span>
        {% endif %}
        {# end edits #}
        </div>
      </div>

      <!-- Button to open search dialogue -->
      <div class="md-flex__cell md-flex__cell--shrink">
        {% if "search" in config["plugins"] %}
          <label class="md-icon md-icon--search md-header-nav__button"
              for="__search"></label>

          <!-- Search interface -->
          {% include "partials/search.html" %}
        {% endif %}
      </div>

      <!-- Repository containing source -->
      {% if config.repo_url %}
        <div class="md-flex__cell md-flex__cell--shrink">
          <div class="md-header-nav__source">
            {% include "partials/source.html" %}
          </div>
        </div>
      {% endif %}
    </div>
  </nav>
</header>
